import { app } from '@/app.ts';
import { AiAgent } from '@/models/agent.ts';
import { ChatPrompt } from '@/models/chat-prompt.ts';
import { Prompt } from '@/models/prompt.ts';
import { CustomError } from '@kevisual/router';

// Admin only
app
  .route({
    path: 'chat-prompt',
    key: 'list',
    // middleware: ['auth'],
  })
  .define(async (ctx) => {
    const chatPrompt = await ChatPrompt.findAll({
      order: [['updatedAt', 'DESC']],
      // 列出被删除的
      // paranoid: false,
    });
    ctx.body = chatPrompt;
  })
  .addTo(app);

app
  .route({
    path: 'chat-prompt',
    key: 'get',
    validator: {
      id: {
        type: 'string',
        required: true,
      },
    },
  })
  .define(async (ctx) => {
    const { id } = ctx.query;
    const chatPrompt = await ChatPrompt.findByPk(id);
    if (!chatPrompt) {
      throw new CustomError('ChatPrompt not found');
    }
    ctx.body = chatPrompt;
  })
  .addTo(app);

app
  .route({
    path: 'chat-prompt',
    key: 'update',
    middleware: ['auth'],
  })
  .define(async (ctx) => {
    const tokenUser = ctx.state.tokenUser;
    const uid = tokenUser.id;
    const { data } = ctx.query;
    const { id, ...rest } = data;
    if (id) {
      const page = await ChatPrompt.findByPk(id);
      if (page) {
        if (rest.data) {
          rest.data = { ...page.data, ...rest.data };
        }
        const newPage = await page.update(rest);
        ctx.body = newPage;
      } else {
        throw new CustomError('page not found');
      }
    } else if (data) {
      const page = await ChatPrompt.create({ ...rest, uid });
      ctx.body = page;
    }
  })
  .addTo(app);

app
  .route({
    path: 'chat-prompt',
    key: 'delete',
    validator: {
      id: {
        type: 'string',
        required: true,
      },
    },
    middleware: ['auth'],
  })
  .define(async (ctx) => {
    const id = ctx.query.id;
    const chatPrompt = await ChatPrompt.findByPk(id);
    if (!chatPrompt) {
      throw new CustomError('chatPrompt not found');
    }
    await chatPrompt.destroy();
    ctx.body = 'success';
  })
  .addTo(app);
app
  .route({
    path: 'chat-prompt',
    key: 'getByKey',
    middleware: ['auth'],
  })
  .define(async (ctx) => {
    const { key } = ctx.query.data || {};
    if (!key) {
      throw new CustomError('key is required');
    }
    const chatPrompt = await ChatPrompt.findOne({
      where: { key },
    });
    if (!chatPrompt) {
      throw new CustomError('chatPrompt not found');
    }
    const { promptId, aiAgentId } = chatPrompt.data;
    if (!aiAgentId) {
      throw new CustomError('promptId is required');
    }
    const aiAgent = await AiAgent.findByPk(aiAgentId, {
      // 只获取 id 和description 字段
      attributes: ['id', 'description', 'key'],
    });
    if (!aiAgent) {
      throw new CustomError('aiAgent not found');
    }
    const prompt = await Prompt.findByPk(promptId);
    ctx.body = {
      chatPrompt: chatPrompt,
      aiAgent,
      prompt,
    };
  })
  .addTo(app);
